@@ -1,4 +1,4 @@
-__version__         = '0.4.10'
+__version__         = '0.4.12'
 __author__          = "Dave Martorana (http://davemartorana.com), Richard Cooper (http://frozenskys.com), Bill Jones (oraclebill), Dmitry Golomidov (deeGraYve)"
 __date__            = '2010-April-14'
 __url__             = 'http://postmarkapp.com'
@@ -84,5 +84,4 @@ __doc__ = '''
 
 '''
 
-
-from .core import *
+from postmark.core import *
